@@ -1,13 +1,13 @@
 use crate::common::*;
 
 #[derive(Debug)]
-pub enum Command {
+pub(crate) enum Command {
   Vim,
   Neovim,
 }
 
-impl fmt::Display for Command {
-  fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
+impl Display for Command {
+  fn fmt(&self, f: &mut Formatter<'_>) -> fmt::Result {
     match self {
       Command::Vim => write!(f, "vim"),
       Command::Neovim => write!(f, "nvim"),
