@@ -1,7 +1,7 @@
 use crate::common::*;
 
 #[derive(Debug)]
-pub struct Printer {
+pub(crate) struct Printer {
   reverse: bool,
   count:   Option<usize>,
   prec:    Option<usize>,
@@ -28,17 +28,17 @@ impl Printer {
     );
 
     println!("{}", header);
-    println!("{}", utils::repeat("=", header.len()));
+    println!("{}", repeat("=", header.len()));
 
     for (i, plugin) in plugins.iter().enumerate() {
       println!(
         "{} {} {:10}",
-        format!("{:<1$}", i + 1, plugins.len().to_string().len() + 2),
-        format!("{:1$}", plugin.name, &plugins.len_largest()),
-        format!("{:.1$}", plugin.average(), self.prec.unwrap_or(2_usize))
+        format_args!("{:<1$}", i + 1, plugins.len().to_string().len() + 2),
+        format_args!("{:1$}", plugin.name, &plugins.len_largest()),
+        format_args!("{:.1$}", plugin.average(), self.prec.unwrap_or(2_usize))
       );
     }
 
-    println!("{}", utils::repeat("=", header.len()));
+    println!("{}", repeat("=", header.len()));
   }
 }
